package com.example.nto_minipigs.ui.screens.Main

import androidx.compose.foundation.layout.Arrangement
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.shape.RoundedCornerShape
import androidx.compose.material3.Button
import androidx.compose.material3.CircularProgressIndicator
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedTextField
import androidx.compose.material3.Surface
import androidx.compose.material3.Text
import androidx.compose.material3.rememberDateRangePickerState
import androidx.compose.runtime.Composable
import androidx.compose.runtime.LaunchedEffect
import androidx.compose.runtime.mutableStateOf
import androidx.compose.runtime.remember
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import com.example.nto_minipigs.ui.theme.Nto_minipigsTheme
import androidx.compose.runtime.getValue
import androidx.compose.runtime.livedata.observeAsState
import androidx.compose.runtime.setValue
import androidx.compose.ui.unit.dp
import com.example.nto_minipigs.UserData

@Composable
fun MainScreen( viewModel: MainViewModel, token: String?) {
    Nto_minipigsTheme {
        val data = viewModel.data.observeAsState()
        Surface {
            Column(
                modifier = Modifier.fillMaxSize(),
                verticalArrangement = Arrangement.Center,
                horizontalAlignment = Alignment.CenterHorizontally,
            ) {
                when(val result = data.value){
                    is NetworkResponse.Error -> {
                        Text(text = result.message)
                    }
                    NetworkResponse.Loading -> {
                        CircularProgressIndicator()
                    }
                    is NetworkResponse.Success -> {
                        Text(text = result.data.toString())
                    }
                    null -> {}
                }

                Button(
                    onClick = { viewModel.Fetch(token) },
                    shape = RoundedCornerShape(12.dp),
                ) {
                    Text(text = "Sign In", style = MaterialTheme.typography.bodyLarge)
                }
            }
        }

        LaunchedEffect(Unit) {
            viewModel.Fetch(token)
        }
    }
}
